@@ -294,10 +294,13 @@ class JSON2EDCLineageFiles:
         for entity in entities:
             entity_attributes = self.get_attributes(entity)
             # print("Entity >%s< #attributes >%d<" % (entity, len(entity_attributes)))
-            for entity_attribute in entity_attributes:
-                if entity_attribute["uid"] == attribute:
-                    print("Found: entity_attribute >%s< is named >%s<" % (entity_attribute["uid"], entity_attribute["name"]))
-                    return True, entity, entity_attribute["name"]
+            if entity_attributes is None:
+                print("Could not determine attributes for entity >%s<" % entity)
+            else:
+                for entity_attribute in entity_attributes:
+                    if entity_attribute["uid"] == attribute:
+                        print("Found: entity_attribute >%s< is named >%s<" % (entity_attribute["uid"], entity_attribute["name"]))
+                        return True, entity, entity_attribute["name"]
         print("NOT FOUND: attribute >%s< in entity list >%s<" % (attribute, str(entities)))
         return False, None, None
 
