@@ -1,4 +1,4 @@
-from excel2meta_interface.utils import messages
+from excel2meta_interface.utils import messages, check_schema
 import logging
 import jinja2
 import json
@@ -30,3 +30,11 @@ class UtilsHelper:
             return messages.message["jinja_template_not_found"], None
 
         return messages.message["ok"], the_template
+
+    def get_json(self, json_file):
+        with open(json_file) as f:
+            data = json.load(f)
+        return data
+
+    def check_schema(self, base_schema_folder, data):
+        return check_schema.CheckSchema().check_schema(base_schema_folder=base_schema_folder, data=data)
